@@ -3,17 +3,17 @@ use warnings;
 use feature qw( state );
 
 package WWW::RoboCop;
-our $VERSION = '0.000100';
-use Carp qw( croak );
+our $VERSION = '0.000101';
+
 use Moo;
+
 use MooX::HandlesVia;
 use MooX::StrictConstructor;
-use Mozilla::CA;
-use Type::Params qw( compile );
+use Type::Params    qw( compile );
 use Types::Standard qw( CodeRef HashRef InstanceOf );
-use Types::URI -all;
-use URI;
-use WWW::Mechanize;
+use Types::URI      qw( Uri );
+use URI             ();
+use WWW::Mechanize  ();
 
 has is_url_allowed => (
     is          => 'ro',
@@ -126,13 +126,13 @@ WWW::RoboCop - Police your URLs!
 
 =head1 VERSION
 
-version 0.000100
+version 0.000101
 
 =head1 SYNOPSIS
 
     use feature qw( state );
 
-    use WWW::RoboCop;
+    use WWW::RoboCop ();
 
     my $robocop = WWW::RoboCop->new(
         is_url_allowed => sub {
@@ -141,7 +141,7 @@ version 0.000100
         },
     );
 
-    $robocop->crawl( 'http://host.myhost.com/start' );
+    $robocop->crawl( 'https://example.com' );
 
     my %history = $robocop->get_report;
 
@@ -151,11 +151,12 @@ version 0.000100
     #    ...
     # )
 
+See C<examples/crawl-host.pl>, which is included with this distribution, to get a
+quick start.
+
 =head1 DESCRIPTION
 
-BETA BETA BETA!
-
-C<WWW::RoboCop> is a dead simple, somewhat opinionated robot.  Given a starting
+C<WWW::RoboCop> is a simple, somewhat opinionated robot.  Given a starting
 page, this module will crawl only URLs which have been allowed by the
 C<is_url_allowed> callback.  It then creates a report of all visited pages,
 keyed on URL.  You are encouraged to provide your own report creation callback
@@ -180,8 +181,8 @@ Your sub might look something like this:
 
     use feature qw( state );
 
-    use URI;
-    use WWW::RoboCop;
+    use URI ();
+    use WWW::RoboCop ();
 
     my $robocop = WWW::RoboCop->new(
         is_url_allowed => sub {
@@ -252,9 +253,9 @@ while under development, consider providing a L<WWW::Mechanize::Cached> object.
 This can give you enough of a speedup to save you from getting distracted
 and going off to read Hacker News while you wait.
 
-    use CHI;
-    use WWW::Mechanize::Cached;
-    use WWW::RoboCop;
+    use CHI ();
+    use WWW::Mechanize::Cached ();
+    use WWW::RoboCop ();
 
     my $cache = CHI->new(
         driver => 'File',
@@ -293,8 +294,8 @@ The default report looks something like this:
     #    'http://myhost.com/two' => { status => 404, ... },
     # )
 
-See examples/crawl-host.pl, which is included with this distribution, to get a
-dump of the default report.
+See C<examples/crawl-host.pl>, which is included with this distribution, to get
+a dump of the default report.
 
 =head1 AUTHOR
 
